@@ -4,7 +4,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, you can obtain one at https://mozilla.org/MPL/2.0/.
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
@@ -337,7 +337,7 @@ ninfo14			NINFO	"foo\;"
 ninfo15			NINFO	"bar\\;"
 
 ; type 57
-rkey01			RKEY	0 ( 255 1 AQMFD5raczCJHViKtLYhWGz8hMY
+rkey01			RKEY	512 ( 255 1 AQMFD5raczCJHViKtLYhWGz8hMY
 				9UGRuniJDBzC7w0aRyzWZriO6i2odGWWQVucZqKV
 				sENW91IOW4vqudngPZsY3GvQ/xVA8/7pyFj6b7Esg
 				a60zyGW6LFe9r8n6paHrlG5ojqf0BaqHT+8= )
@@ -368,14 +368,7 @@ openpgpkey		OPENPGPKEY	( AQMFD5raczCJHViKtLYhWGz8hMY
 csync01			CSYNC	0 0 A NS AAAA
 csync02			CSYNC	0 0
 
-;type	63
-zonemd01		ZONEMD	2019020700 1 0 (
-                                C220B8A6ED5728A971902F7E3D4FD93A
-                                DEEA88B0453C2E8E8C863D465AB06CF3
-                                4EB95B266398C98B59124FA239CB7EEB
-				)
-
-; type 64 -- 98 (unassigned)
+; type 63 -- 98 (unassigned)
 
 ; type 99
 spf01			SPF	"v=spf1 -all"
@@ -390,8 +383,7 @@ uid01			UID	\# 1 02
 ; type 102 (GID - not implemented by BIND - unknown record format only)
 gid01			GID	\# 1 03
 
-; type 103 (UNSPEC - not implemented by BIND - unknown record format only)
-unspec01		UNSPEC	\# 1 04
+; type 103 (UNSPEC - XXXMUKS TODO - this has some weird encoding - see btoa_totext())
 
 ; type 104
 nid			NID	10 0014:4fff:ff20:ee64
@@ -463,15 +455,7 @@ doa01			DOA	( 1234567890 1234567890 1 "image/gif"
 				  hmsBich1awPAjkY1SZR8bJWrz382SGqIBQQFQd4IsUTaX+ceuudPEQA7 )
 doa02			DOA	0 1 2 "" aHR0cHM6Ly93d3cuaXNjLm9yZy8=
 
-; type 260
-amtrelay01		AMTRELAY 0 0 0
-amtrelay02		AMTRELAY 0 1 0
-amtrelay03		AMTRELAY 0 0 1 0.0.0.0
-amtrelay04		AMTRELAY 0 0 2 ::
-amtrelay05		AMTRELAY 0 0 3 example.net.
-amtrelay06		AMTRELAY \# 2 0004
-
-; type 261 -- 32767 (unassigned)
+; type 260 -- 32767 (unassigned)
 
 ; type 32768
 ta			TA	30795 1 1 (
