@@ -79,7 +79,7 @@ then
 else
 	echo_i "testing plain file failed (unexpected)"
 	echo_i "exit status: 1"
-	exit 1 
+	exit 1
 fi
 
 # Now try directory, expect failure
@@ -130,7 +130,7 @@ else
 	echo_i "skipping pipe test (unable to create pipe)"
 fi
 
-# Now try symlink file to plain file, expect success 
+# Now try symlink file to plain file, expect success
 n=`expr $n + 1`
 echo_i "testing symlink to plain file as log file (named -g) ($n)"
 # Assume success
@@ -159,7 +159,7 @@ fi
 # files while controlling the stop/start of the server.
 # Have to stop the stock server because it uses "-g"
 #
-$PERL ../../stop.pl .. ns1
+$PERL ../../stop.pl logfileconfig ns1
 
 $myNAMED > /dev/null 2>&1
 
@@ -187,7 +187,7 @@ then
 else
 	echo_i "testing plain file failed (unexpected)"
 	echo_i "exit status: 1"
-	exit 1 
+	exit 1
 fi
 
 # Now try directory, expect failure
@@ -238,7 +238,7 @@ else
 	echo_i "skipping pipe test (unable to create pipe)"
 fi
 
-# Now try symlink file to plain file, expect success 
+# Now try symlink file to plain file, expect success
 n=`expr $n + 1`
 echo_i "testing symlink to plain file as log file ($n)"
 # Assume success
@@ -269,7 +269,7 @@ n=`expr $n + 1`
 echo_i "testing default logfile using named -L file ($n)"
 # Now stop the server again and test the -L option
 rm -f $DLFILE
-$PERL ../../stop.pl .. ns1
+$PERL ../../stop.pl logfileconfig ns1
 if ! test -f $PIDFILE; then
 	copy_setports $PLAINCONF named.conf
 	$myNAMED -L $DLFILE > /dev/null 2>&1
@@ -333,7 +333,7 @@ if test ${t:-1000} -gt 5
 then
         echo_i "testing explicit versions failed: cleanup of old entries took too long ($t secs)"
 	status=`expr $status + 1`
-fi 
+fi
 if ! grep "status: NOERROR" dig.out.test$n > /dev/null
 then
 	echo_i "testing explicit versions failed: DiG lookup failed"
@@ -369,7 +369,7 @@ if test ${t:-1000} -gt 5
 then
         echo_i "testing timestamped versions failed: cleanup of old entries took too long ($t secs)"
 	status=`expr $status + 1`
-fi 
+fi
 if ! grep "status: NOERROR" dig.out.test$n > /dev/null
 then
 	echo_i "testing timestamped versions failed: DiG lookup failed"
@@ -395,7 +395,7 @@ if test ${t:-1000} -gt 5
 then
         echo_i "testing unlimited versions failed: took too long ($t secs)"
 	status=`expr $status + 1`
-fi 
+fi
 if ! grep "status: NOERROR" dig.out.test$n > /dev/null
 then
 	echo_i "testing unlimited versions failed: DiG lookup failed"
