@@ -68,11 +68,7 @@
 #include "dlz_minimal.h"
 
 /* should the bdb driver use threads. */
-#ifdef ISC_PLATFORM_USETHREADS
 #define bdbhpt_threads DB_THREAD
-#else
-#define bdbhpt_threads 0
-#endif
 
 /* bdbhpt database names */
 #define dlz_data   "dns_data"
@@ -492,7 +488,7 @@ dlz_findzonedb(void *dbdata, const char *name,
 
 	/*
 	 * reverse string to take advantage of BDB locality of reference
-	 * if we need further lookups because the zone doesn't match the
+	 * if we need futher lookups because the zone doesn't match the
 	 * first time.
 	 */
 	key.data = bdbhpt_strrev(key.data);
@@ -708,7 +704,7 @@ dlz_create(const char *dlzname, unsigned int argc, char *argv[],
 
 		/*
 		 * Private mode. No inter-process communication & no locking.
-		 * Lowest safety - highest speed.
+		 * Lowest saftey - highest speed.
 		 */
 	case 'P':
 	case 'p':
