@@ -20,6 +20,7 @@
 #include <isc/hex.h>
 #include <isc/iterated_hash.h>
 #include <isc/log.h>
+#include <isc/md.h>
 #include <isc/string.h>
 #include <isc/util.h>
 #include <isc/safe.h>
@@ -2099,13 +2100,12 @@ dns_nsec3_noexistnodata(dns_rdatatype_t type, const dns_name_t *name,
 			*exists = false;
 			*data = false;
 			if (optout != NULL) {
-				if ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT) != 0)
-					(*logit)(arg, ISC_LOG_DEBUG(3),
-						 "NSEC3 indicates optout");
-				else
-					(*logit)(arg, ISC_LOG_DEBUG(3),
-						 "NSEC3 indicates secure range");
-				*optout = (nsec3.flags & DNS_NSEC3FLAG_OPTOUT);
+				*optout = ((nsec3.flags & DNS_NSEC3FLAG_OPTOUT)
+					   != 0);
+				(*logit)(arg, ISC_LOG_DEBUG(3),
+					 (*optout
+					  ? "NSEC3 indicates optout"
+					  : "NSEC3 indicates secure range"));
 			}
 			answer = ISC_R_SUCCESS;
 		}
