@@ -27,7 +27,6 @@
 #define UNIT_TESTING
 #include <cmocka.h>
 
-#include <isc/print.h>
 #include <isc/serial.h>
 #include <isc/stdtime.h>
 #include <isc/util.h>
@@ -307,7 +306,7 @@ main(void) {
 						_setup, _teardown),
 	};
 
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (cmocka_run_group_tests(tests, NULL, NULL));
 }
 
 #else /* HAVE_CMOCKA */
